@@ -10,7 +10,7 @@ def SampleCurves(sample, N=500):
     assert( N >= 2 )
     SUM = Curve([(0,0), (1,1)])
     AREA = []
-    for i in xrange(options.samples):
+    for i in xrange(samples):
         C = F(S.sweep_threshold_random())
         SUM += C
         AREA.append(C.area())
@@ -450,8 +450,8 @@ class Curve:
         """
         x = float(x); y = float(y)
         if len(self) >= 1 :
-            assert( x >= self[-1][0] ) #assert that x monotonically increases.
-            assert( y >= self[-1][1] ) #assert that y monotonically increases.
+            assert( x >= self[-1][0] - 0.000001 ) #assert that x monotonically increases.
+            assert( y >= self[-1][1] - 0.000001 ) #assert that y monotonically increases.
             if (x,y) == self[-1]: return #no need to append duplicate point
 
         if len(self)>=2:
